affinidi_tdk_vault_data_manager library

This library allows accessing vault VFS on Cloud

Classes

VaultDataManagerApiService
A service class that implements the VaultDataManagerApiServiceInterface. This class provides the API service layer for managing vault data operations.
VaultDataManagerApiServiceInterface
Interface for service that interacts with the Vault Data Manager API
VaultDataManagerEncryptionService
Implementation of the vault data manager encryption service that handles encryption and decryption operations for Data Encryption Keys (DEKs).
VaultDataManagerEncryptionServiceInterface
Interface for the VaultDataManagerEncryptionService used to encrypt and decrypt data encryption keys (DEKs) using both wallet-based and API-based methods.
VaultDataManagerService
Implementation of VaultDataManagerServiceInterface that handles encrypted storage operations using vault data manager services.
VaultDataManagerServiceInterface
Interface for secure storage operations with encryption support.
VaultDataManagerSharedAccessApiService
A service to grant or revoke shared access to vault cloud storages.
VaultDataManagerSharedAccessApiServiceInterface
Interface to manage shared access for vault cloud storages.
VFSFileStorage
A VFS based implementation of FileStorage for managing files and folders.
VfsProfileRepository
A VFS implementation of ProfileRepository for managing user profiles.
VfsSharedStorage
A VFS-based implementation of vault.SharedStorage that combines credential and file storage.

Typedefs

ConsumerAuthProviderFactory = ConsumerAuthProvider Function(DidSigner didSigner, {Dio? client})
Type definition for creating ConsumerAuthProvider instances
IamApiServiceFactory = VaultDataManagerSharedAccessApiServiceInterface Function(ConsumerAuthProvider provider)
Factory function type for creating VaultDataManagerSharedAccessApiService instances.
VaultDataManagerServiceFactory = Future<VaultDataManagerServiceInterface> Function({required Uint8List encryptedDekek, required KeyPair keyPair})
Type definition for creating regular VaultDataManagerService instances
VaultDelegatedDataManagerServiceFactory = Future<VaultDataManagerServiceInterface> Function({required Uint8List encryptedDekek, required KeyPair keyPair, required String profileDid})
Type definition for creating delegated VaultDataManagerService instances